import React from "react";
import {
  Box,
  Text,
  Heading,
  Flex,
  Image,
  VStack,
  Grid,
  GridItem,
} from "@chakra-ui/react";
import ImageWithFallback from "@/components/image/ImageWithFallback";
import moment from "moment";
import { IDCForm } from "@/types/dc-form";

const DcView = ({ dc }: { dc: IDCForm }) => {
  return (
    <Box p="5" borderWidth="1px" borderRadius="lg" shadow="md">
      <Heading as="h2" size="lg" mb="4">
        Consumer Details
      </Heading>
      <Grid templateColumns="repeat(2, 1fr)" gap={4}>
        <GridItem>
          <Text fontWeight="bold">Contact Person:</Text>
          <Text>{dc.contact_person}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Mobile No:</Text>
          <Text>{dc.mobile_no}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Dc Perform:</Text>
          <Text>{dc.dc_perform == 1 ? "Yes" : "No"}</Text>
        </GridItem>

        {dc?.dc_perform == 0 && (
          <GridItem>
            <Text fontWeight="bold">No Dc Perform Reason</Text>
            <Text>{dc.dc_perform_reason}</Text>
          </GridItem>
        )}
        <GridItem>
          <Text fontWeight="bold">Meter/Unmeter:</Text>
          <Text>{dc.meter_un_meter ? "Yes" : "No"}</Text>
        </GridItem>
        {dc?.meter_un_meter == 1 && (
          <>
            <GridItem>
              <Text fontWeight="bold">Meter No:</Text>
              <Text>{dc.meter_no}</Text>
            </GridItem>
            <GridItem>
              <Text fontWeight="bold">Meter Reading:</Text>
              <Text>{dc.meter_reading}</Text>
            </GridItem>
          </>
        )}
        {dc?.meter_un_meter == 0 && (
          <GridItem>
            <Text fontWeight="bold">Un Meter Reason:</Text>
            <Text>{dc.un_meter_reason}</Text>
          </GridItem>
        )}

        <GridItem>
          <Text fontWeight="bold">Paid Amount:</Text>
          <Text>{dc.paid_amount}</Text>
        </GridItem>

        <GridItem>
          <Text fontWeight="bold">Category:</Text>
          <Text>{dc.category || "N/A"}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Remarks:</Text>
          <Text>{dc.remarks || "N/A"}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Remarks:</Text>
          <Text>{dc.additional_remarks || "N/A"}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Latitude:</Text>
          <Text>{dc.latitude}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Longitude:</Text>
          <Text>{dc.longitude}</Text>
        </GridItem>
        <GridItem colSpan={2}>
          <Text fontWeight="bold">Created By:</Text>
          <Text>
            {dc.created_by.first_name} {dc.created_by.last_name || ""}
          </Text>
        </GridItem>
        <GridItem colSpan={2}>
          <Text fontWeight="bold">Created At:</Text>
          <Text>{moment(dc.created_at).format("DD/MM/YYYY, hh:mm A")}</Text>
        </GridItem>
      </Grid>

      <VStack align="start" mt="6">
        <Heading as="h3" size="md" mb="2">
          Attachments
        </Heading>
        {dc.attachments.length > 0 ? (
          <Flex gap="4" wrap="wrap">
            {dc.attachments.map((attachment) => (
              <Box key={attachment.id} borderWidth="1px" borderRadius="md" p="2">
                <ImageWithFallback attachment={attachment} />
                <Text mt="2" fontSize="sm">
                  {attachment.file.filename}
                </Text>
              </Box>
            ))}
          </Flex>
        ) : (
          <Text>No attachments available.</Text>
        )}
      </VStack>
    </Box>
  );
};

export default DcView;
